==> cronapp-framework-java-2.3.2.jar: cronapp/framework/authentication/normal/AuthenticationConfigurer.java <==
package cronapp.framework.authentication.normal;

import com.google.gson.JsonObject;
import cronapi.AppConfig;
import cronapp.framework.api.ApiManager;
import cronapp.framework.authentication.social.SocialConfig;
import cronapp.framework.i18n.Messages;
import cronapp.framework.tenant.TenantComponent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.AuthenticationServiceException;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.util.Set;

import static cronapp.framework.authentication.external.ExternalAuthenticationConfig.*;

@Component
public class AuthenticationConfigurer implements AuthenticationProvider {
  
  private static final Logger log = LoggerFactory.getLogger(AuthenticationConfigurer.class);
  
  @Autowired
  private HttpServletRequest request;

  @Autowired(required = false)
  private TenantComponent tenantComponent;
  
  @Override
  @SuppressWarnings("unchecked")
  public Authentication authenticate(Authentication authentication) throws AuthenticationException {
    try {
      Messages.set(request.getLocale());
      String name = authentication.getName();
      boolean isOauth = authentication.getAuthorities().contains(new SimpleGrantedAuthority("#OAUTH#"));
      String rawPassword = authentication.getCredentials().toString();
      String type = null;
      boolean autoSignUp = false;
      boolean externalAuthenticationSuccess = false;

      if (isOauth) {
        //Enviando o provider pelo password
        type = rawPassword;
        autoSignUp = SocialConfig.isAutoSignUp();
      }

      if (name.equals("#OAUTH#")) {
        name = (String) request.getSession().getAttribute("#OAUTH#USER");
        isOauth = true;
        request.getSession().removeAttribute("#OAUTH#USER");
      }

      if (isExternalAuth() && authenticateExternally(name, rawPassword)) {
        type = getExternalAuthType();
        externalAuthenticationSuccess = true;
        autoSignUp = autoSignUp || AppConfig.autoSignUp();
      }

      ApiManager apiManager = ApiManager.byUserAndPassword(name, rawPassword, type, autoSignUp, authentication.getDetails() instanceof JsonObject ? (JsonObject) authentication.getDetails() : null);
      
      if (authentication instanceof UsernamePasswordAuthenticationToken) {
        ((UsernamePasswordAuthenticationToken) authentication).setDetails(null);
      }
      
      try {
        cronapp.framework.api.User user = apiManager.getUser();

        if (user == null) {
          throw new UsernameNotFoundException(Messages.getString("UserNotFound"));
        }

        if (isExternalAuth() && (!isOauth && !externalAuthenticationSuccess)) {
          throw new BadCredentialsException(Messages.getString("UserOrPassordInvalids"));
        }

        String password = user.getPassword();

        if (!isExternalAuth() && (!isOauth && !apiManager.passwordMatches(rawPassword, password))) {
          throw new BadCredentialsException(Messages.getString("UserOrPassordInvalids"));
        }

        Set<GrantedAuthority> authorities = apiManager.getAuthorities();
        User userDetails = new User(name, rawPassword, false, false, false, false, authorities);
        UsernamePasswordAuthenticationToken userToken = new UsernamePasswordAuthenticationToken(userDetails, password, authorities);
        userToken.setDetails(userDetails);

        String theme = user.getTheme();
        if (theme == null) {
          theme = "";
        }

        HttpSession session = request.getSession();
        session.setAttribute("theme", theme);

        request.setAttribute("userDetails", user);

        if (tenantComponent != null) {
          tenantComponent.authenticationTenant(user.getUsername());
        }

        return userToken;
      } catch (Exception e) {
        log.error(Messages.getString("AuthError", e.getMessage()), e);
        throw new AuthenticationServiceException(Messages.getString("AuthError", e.getMessage()));
      }
    } finally {
      Messages.remove();
    }
  }
  
  @Override
  public boolean supports(Class<?> authentication) {
    return authentication.equals(UsernamePasswordAuthenticationToken.class);
  }
  
}

==> cronapp-framework-java-2.9.0.jar: cronapp/framework/authentication/normal/AuthenticationConfigurer.java <==
package cronapp.framework.authentication.normal;

import com.google.gson.JsonObject;
import cronapi.AppConfig;
import cronapp.framework.LockedUserException;
import cronapp.framework.api.ApiManager;
import cronapp.framework.authentication.security.CronappUserDetails;
import cronapp.framework.authentication.social.SocialConfig;
import cronapp.framework.authentication.token.google.CaptchaVerify;
import cronapp.framework.i18n.Messages;
import cronapp.framework.tenant.TenantComponent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.lang.Nullable;
import org.springframework.security.authentication.AuthenticationProvider;
import org.springframework.security.authentication.AuthenticationServiceException;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Component;
import org.springframework.util.Assert;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.util.Collection;

import static cronapp.framework.authentication.external.ExternalAuthenticationConfig.*;

@Component
public class AuthenticationConfigurer implements AuthenticationProvider {

  private static final Logger log = LoggerFactory.getLogger(AuthenticationConfigurer.class);

  private HttpServletRequest request;

  private TenantComponent tenantComponent;

  private final CaptchaVerify captchaVerify;

  public AuthenticationConfigurer(HttpServletRequest request, @Nullable TenantComponent tenantComponent) {
    this.request = request;
    this.tenantComponent = tenantComponent;
    this.captchaVerify = new CaptchaVerify();
  }

  @Override
  @SuppressWarnings("unchecked")
  public Authentication authenticate(Authentication authentication) throws AuthenticationException {
    try {
      Messages.set(request.getLocale());
      String name = authentication.getName();
      boolean isOauth = authentication.getAuthorities().contains(new SimpleGrantedAuthority("#OAUTH#"));
      String rawPassword = authentication.getCredentials().toString();
      String type = null;
      boolean autoSignUp = false;
      boolean externalAuthenticationSuccess = false;

      if (isOauth) {
        //Enviando o provider pelo password
        type = rawPassword;
        autoSignUp = SocialConfig.isAutoSignUp();
      }

      if (name.equals("#OAUTH#") && request.getSession().getAttribute("#OAUTH#USER") != null) {
        name = (String) request.getSession().getAttribute("#OAUTH#USER");
        isOauth = true;
        request.getSession().removeAttribute("#OAUTH#USER");
      }

      Authentication externalToken = null;
      CronappUserDetails externalUserDetails = null;

      if (isExternalAuth()) {
        externalToken = authenticateExternally(new UsernamePasswordAuthenticationToken(name, rawPassword));
        type = getExternalAuthType();
        externalAuthenticationSuccess = true;
        autoSignUp = autoSignUp || AppConfig.autoSignUp();

        if (externalToken.getPrincipal() instanceof CronappUserDetails) {
          externalUserDetails = (CronappUserDetails) externalToken.getPrincipal();
        }
      }

      ApiManager apiManager = ApiManager.byUserAndPassword(name, rawPassword, type, autoSignUp, authentication.getDetails() instanceof JsonObject ? (JsonObject) authentication.getDetails() : null);
      if (authentication instanceof UsernamePasswordAuthenticationToken) {
        ((UsernamePasswordAuthenticationToken) authentication).setDetails(null);
      }

      cronapp.framework.api.User userNoPassword = null;
      try {
        userNoPassword = ApiManager.byUser(name).getUser();

        if (ApiManager.isUserLocked(userNoPassword)) {
          throw new LockedUserException(Messages.getString("UserLocked"));
        }

        verifyRecaptcha(name, request);

        cronapp.framework.api.User user = apiManager.getUser(externalUserDetails);

        if (user == null) {
          throw new UsernameNotFoundException(Messages.getString("UserNotFound"));
        }

        if (isExternalAuth() && (!isOauth && !externalAuthenticationSuccess)) {
          throw new BadCredentialsException(Messages.getString("UserOrPassordInvalids"));
        }

        String password = user.getPassword();

        if (!isExternalAuth() && (!isOauth && !apiManager.passwordMatches(rawPassword, password))) {
          throw new BadCredentialsException(Messages.getString("UserOrPassordInvalids"));
        }

        Collection<? extends GrantedAuthority> authorities;

        if (externalUserDetails == null) {
          authorities = apiManager.getAuthorities();
        } else {
          authorities = externalUserDetails.getAuthorities();
        }

        User userDetails = new User(name, rawPassword, false, false, false, false, authorities);
        UsernamePasswordAuthenticationToken userToken = new UsernamePasswordAuthenticationToken(userDetails, password, authorities);
        userToken.setDetails(userDetails);

        String theme = user.getTheme();
        if (theme == null) {
          theme = "";
        }

        HttpSession session = request.getSession();
        session.setAttribute("theme", theme);

        request.setAttribute("userDetails", user);

        if (tenantComponent != null) {
          tenantComponent.authenticationTenant(user.getUsername());
        }
        ApiManager.unlockUser(userNoPassword);
        return userToken;
      } catch (Exception e) {
        ApiManager.attemptFailed(userNoPassword);


        if (!ApiManager.isUserLocked(userNoPassword) && ApiManager.getFailedAttempts(userNoPassword) > AppConfig.getFailedAttempts()) {
          ApiManager.lockUser(userNoPassword);
        }

        log.error(Messages.getString("AuthError", e.getMessage()), e);
        throw new AuthenticationServiceException(Messages.getString("AuthError", e.getMessage()));
      }
    } finally {
      Messages.remove();
    }
  }

  @Override
  public boolean supports(Class<?> authentication) {
    return authentication.equals(UsernamePasswordAuthenticationToken.class);
  }  private void verifyRecaptcha(String username, HttpServletRequest request) {
    try {
      Assert.isTrue(captchaVerify.processRequest(username, request), "");
    } catch (Exception e) {
      log.error(Messages.getString("AuthError", e.getMessage()), e);
      throw new AuthenticationServiceException(Messages.getString("AuthError", e.getMessage()));
    }
  }
}
